/**
 * JASMINe
 * Copyright (C) 2006,2007 Bull S.A.S.
 * Contact: jasmine@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id:$
 * --------------------------------------------------------------------------
 */

package org.objectweb.jasmine.jade.application;

import java.net.BindException;
import java.util.Hashtable;

import javax.naming.Context;
import javax.naming.InitialContext;

import org.objectweb.jasmine.jade.ejb.JadeEJBRemote;
import org.ow2.jasmine.JASMINeConstants;

public abstract class Application {

    /**
     *
     */
    protected static JadeEJBRemote jadeBean = null;

    /**
     * @param url
     * @throws Exception
     */
    public final static void setEJBConnexion(String url) throws Exception {
        try {

            Hashtable<String, String> env = new Hashtable<String, String>();
            env.put(Context.INITIAL_CONTEXT_FACTORY,
                    JASMINeConstants.INITIAL_CONTEXT_FACTORY);
            env.put(Context.PROVIDER_URL, url);
            Context initialContext = new InitialContext(env);
            jadeBean = (JadeEJBRemote) initialContext
                    .lookup(JASMINeConstants.JADE_EJB_NAME);
        } catch (Exception e) {
            throw new Exception("can't initialize EJB connexion : ", e);
        }
    }

    public final static void unsetEJBConnexion() {
        jadeBean = null;
    }

    /**
     * @param host
     * @param port
     * @throws Exception
     */
    public final static void setJMXConnection(String host, String port)
            throws Exception {
        if (jadeBean == null)
            return;
        jadeBean.setJMXURL(host, port);
    }

    /**
     * @param host
     * @param port
     * @throws Exception
     */
    public final static void setRMIConnection(String host, int port)
            throws Exception {
        if (jadeBean == null)
            return;
        jadeBean.setRegistry(host, port);
    }

    /**
     * Test if the connection to Jade is OK
     *
     * @throws BindException
     *             thrown if not connected
     */
    public final static void testEJBConnexion() throws BindException {
        if (jadeBean == null) {
            throw new BindException("Not connected to Jade");
        }
    }

}
