/**
 * JASMINe
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id:$
 * --------------------------------------------------------------------------
 */

package org.ow2.jasmine.fdf;

import java.net.BindException;
import java.util.Hashtable;

import javax.naming.Context;
import javax.naming.InitialContext;

import org.ow2.jasmine.JASMINeConstants;
import org.ow2.jasmine.fdf.ejb.FdfEjb;

/**
 *
 *
 * @author Julien Legrand
 *
 */
public class JasmineNodeDeployer {

    /**
     *
     */
    private static FdfEjb jasmineNodeDeployerBean = null;

    // ------------------------------------------------------------------------
    // Singleton
    // ------------------------------------------------------------------------

    /**
     * @return
     * @throws BindException
     */
    public static synchronized FdfEjb getInstance() throws BindException {
        testEJBConnexion();
        return jasmineNodeDeployerBean;
    }

    // ------------------------------------------------------------------------
    // Static methods
    // ------------------------------------------------------------------------

    public static void setEJBConnection(String url) throws Exception {

        try {

            Hashtable<String, String> env = new Hashtable<String, String>();
            env
                    .put(Context.INITIAL_CONTEXT_FACTORY,
                            JASMINeConstants.INITIAL_CONTEXT_FACTORY);
            env.put(Context.PROVIDER_URL, url);
            Context initialContext = new InitialContext(env);
            jasmineNodeDeployerBean = (FdfEjb) initialContext
                    .lookup(JASMINeConstants.FDF_EJB_MAPPED_NAME);
        } catch (Exception e) {
            System.out.println("can't initialize EJB connexion : ");
            e.printStackTrace();
            throw e;
        }

    }

    public static void unsetEJBConnection() {
        jasmineNodeDeployerBean = null;
    }

    // ------------------------------------------------------------------------
    // Private methods
    // ------------------------------------------------------------------------

    /**
     * Test if the connection to the JASMINe Node deployer is OK
     *
     * @throws BindException
     *             thrown if not connected
     */
    public final static void testEJBConnexion() throws BindException {
        if (jasmineNodeDeployerBean == null) {
            throw new BindException(
                    "Not connected to the JASMINe node deployer");
        }
    }

}
